@@ -19,8 +19,9 @@ hasShinyJs <- function(body) {
 }
 
 servedBy <- function(appUrl) {
-
-  if (grepl("\\.shinyapps\\.io$", appUrl$host)) return(SERVER_TYPE$SAI)
+  if (grepl("\\.shinyapps\\.io$", appUrl$host)) {
+    return(SERVER_TYPE$SAI)
+  }
 
   h <- curl::new_handle()
   curl::handle_setopt(
@@ -33,14 +34,14 @@ servedBy <- function(appUrl) {
   df <- curl::handle_cookies(h)
   headers <- curl::parse_headers_list(resp$headers)
 
-  if (nrow(df[df$name == "SSP-XSRF",]) == 1
-    || isTRUE(headers[["x-powered-by"]] %in% c("Express", "Shiny Server", "Shiny Server Pro"))) {
+  if (nrow(df[df$name == "SSP-XSRF", ]) == 1 ||
+    isTRUE(headers[["x-powered-by"]] %in% c("Express", "Shiny Server", "Shiny Server Pro"))) {
     return(SERVER_TYPE$SSP)
-  } else if (nrow(df[which(df$name == "rscid"),]) == 1) {
+  } else if (nrow(df[which(df$name == "rscid"), ]) == 1) {
     return(SERVER_TYPE$RSC)
   } else if (hasShinyJs(rawToChar(resp$content))) {
     return(SERVER_TYPE$SHN)
   } else {
-    stop(paste("Target URL", appUrl$build(), "does not appear to be a Shiny application."))
+    cli::cli_abort(paste("Target URL", appUrl$build(), "does not appear to be a Shiny application."))
   }
 }
